==> beamlit-0.0.56rc104.tar.gz: beamlit-0.0.56rc104/docs/beamlit/functions/mcp/mcp.md <==
Module beamlit.functions.mcp.mcp
================================
This module provides functionalities to interact with MCP (Multi-Client Platform) servers.
It includes classes for managing MCP clients, creating dynamic schemas, and integrating MCP tools into Beamlit.

Functions
---------

`configure_field(name: str, type_: dict[str, typing.Any], required: list[str]) ‑> tuple[type, typing.Any]`
:   

`create_schema_model(name: str, schema: dict[str, typing.Any]) ‑> type[pydantic.main.BaseModel]`
:   

Classes
-------

`MCPClient(client: beamlit.client.AuthenticatedClient, url: str)`
:   

    ### Methods

    `call_tool(self, tool_name: str, arguments: dict[str, typing.Any] = None) ‑> requests.models.Response`
    :

    `list_tools(self) ‑> requests.models.Response`
    :

`MCPTool(**kwargs: Any)`
:   Tool for interacting with MCP server-hosted tools.
    
    Attributes:
        client (MCPClient): The MCP client instance.
        handle_tool_error (bool | str | Callable[[ToolException], str] | None): Error handling strategy.
    
    Initialize the tool.

    ### Ancestors (in MRO)

    * langchain_core.tools.base.BaseTool
    * langchain_core.runnables.base.RunnableSerializable[Union[str, dict, ToolCall], Any]
    * langchain_core.runnables.base.RunnableSerializable
    * langchain_core.load.serializable.Serializable
    * pydantic.main.BaseModel
    * langchain_core.runnables.base.Runnable
    * typing.Generic
    * abc.ABC

    ### Class variables

    `client: beamlit.functions.mcp.mcp.MCPClient`
    :

    `handle_tool_error: bool | str | Callable[[langchain_core.tools.base.ToolException], str] | None`
    :

    `model_config`
    :

    ### Instance variables

    `tool_call_schema: type[pydantic.main.BaseModel]`
    :

`MCPToolkit(**data: Any)`
:   Toolkit for managing MCP server tools.
    
    Attributes:
        client (MCPClient): The MCP client instance.
        _tools (ListToolsResult | None): Cached list of tools from the MCP server.
    
    Create a new model by parsing and validating input data from keyword arguments.
    
    Raises [`ValidationError`][pydantic_core.ValidationError] if the input data cannot be
    validated to form a valid model.
    
    `self` is explicitly positional-only to allow `self` as a field name.

    ### Ancestors (in MRO)

    * langchain_core.tools.base.BaseToolkit
    * pydantic.main.BaseModel
    * abc.ABC

    ### Class variables

    `client: beamlit.functions.mcp.mcp.MCPClient`
    :   The MCP session used to obtain the tools

    `model_config`
    :

    ### Methods

    `get_tools(self) ‑> list[langchain_core.tools.base.BaseTool]`
    :   Get the tools in the toolkit.

    `initialize(self) ‑> None`
    :   Initialize the session and retrieve tools list

    `model_post_init(self: BaseModel, context: Any, /) ‑> None`
    :   This function is meant to behave like a BaseModel method to initialise private attributes.
        
        It takes context as an argument since that's what pydantic-core passes when calling it.
        
        Args:
            self: The BaseModel instance.
            context: The context.

==> beamlit-0.0.57rc116.tar.gz: beamlit-0.0.57rc116/docs/beamlit/functions/mcp/mcp.md <==
Module beamlit.functions.mcp.mcp
================================
This module provides functionalities to interact with MCP (Multi-Client Platform) servers.
It includes classes for managing MCP clients, creating dynamic schemas, and integrating MCP tools into Beamlit.

Classes
-------

`MCPClient(client: beamlit.client.AuthenticatedClient, url: str, sse: bool = False)`
:   

    ### Methods

    `call_tool(self, tool_name: str, arguments: dict[str, typing.Any] = None) ‑> requests.models.Response | AsyncIterator[mcp.types.CallToolResult]`
    :

    `list_sse_tools(self) ‑> mcp.types.ListToolsResult`
    :

    `list_tools(self) ‑> mcp.types.ListToolsResult`
    :

`MCPTool(**kwargs: Any)`
:   Tool for interacting with MCP server-hosted tools.
    
    Attributes:
        client (MCPClient): The MCP client instance.
        handle_tool_error (bool | str | Callable[[ToolException], str] | None): Error handling strategy.
        sse (bool): Whether to use SSE streaming for responses.
    
    Initialize the tool.

    ### Ancestors (in MRO)

    * langchain_core.tools.base.BaseTool
    * langchain_core.runnables.base.RunnableSerializable[Union[str, dict, ToolCall], Any]
    * langchain_core.runnables.base.RunnableSerializable
    * langchain_core.load.serializable.Serializable
    * pydantic.main.BaseModel
    * langchain_core.runnables.base.Runnable
    * typing.Generic
    * abc.ABC

    ### Class variables

    `client: beamlit.functions.mcp.mcp.MCPClient`
    :

    `handle_tool_error: bool | str | Callable[[langchain_core.tools.base.ToolException], str] | None`
    :

    `model_config`
    :

    ### Instance variables

    `tool_call_schema: type[pydantic.main.BaseModel]`
    :

`MCPToolkit(**data: Any)`
:   Toolkit for managing MCP server tools.
    
    Attributes:
        client (MCPClient): The MCP client instance.
        _tools (ListToolsResult | None): Cached list of tools from the MCP server.
    
    Create a new model by parsing and validating input data from keyword arguments.
    
    Raises [`ValidationError`][pydantic_core.ValidationError] if the input data cannot be
    validated to form a valid model.
    
    `self` is explicitly positional-only to allow `self` as a field name.

    ### Ancestors (in MRO)

    * langchain_core.tools.base.BaseToolkit
    * pydantic.main.BaseModel
    * abc.ABC

    ### Class variables

    `client: beamlit.functions.mcp.mcp.MCPClient`
    :   The MCP session used to obtain the tools

    `model_config`
    :

    ### Methods

    `get_tools(self) ‑> list[langchain_core.tools.base.BaseTool]`
    :   Get the tools in the toolkit.

    `initialize(self) ‑> None`
    :   Initialize the session and retrieve tools list

    `model_post_init(self: BaseModel, context: Any, /) ‑> None`
    :   This function is meant to behave like a BaseModel method to initialise private attributes.
        
        It takes context as an argument since that's what pydantic-core passes when calling it.
        
        Args:
            self: The BaseModel instance.
            context: The context.
